import 'codemirror/addon/display/placeholder';
import 'codemirror/addon/edit/continuelist';
import 'codemirror/mode/gfm/gfm';
import { fromTextArea } from 'codemirror';
import { Subject } from 'rxjs';
import { trigger, transition } from '@angular/animations';
import { coerceBooleanProperty, coerceNumberProperty } from '@angular/cdk/coercion';
import { isPlatformBrowser, CommonModule } from '@angular/common';
import { InjectionToken, Renderer2, ChangeDetectorRef, Inject, PLATFORM_ID, Optional, Self, ViewChild, ElementRef, Input, Component, ViewEncapsulation, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { NgControl } from '@angular/forms';
import { fadeIn } from '@ng-tangram/components/core';
import { NtFormFieldControl } from '@ng-tangram/components/forms';
import { NtMarkdownModule } from '@ng-tangram/markdown';

const LINE_REGEXP = /^([^\n]*)(\n|$)/gm;
const H1_REGEXP = /^#\s/;
const H1_REGEXP_MULTIPLE = /^(#\s)([^\n]*)(\n|$)/gm;
const H2_REGEXP = /^#{2}\s/;
const H2_REGEXP_MULTIPLE = /^(#{2}\s)([^\n]*)(\n|$)/gm;
const H3_REGEXP = /^#{3}\s/;
const H3_REGEXP_MULTIPLE = /^(#{3}\s)([^\n]*)(\n|$)/gm;
const H4_REGEXP = /^#{4}\s/;
const H4_REGEXP_MULTIPLE = /^(#{4}\s)([^\n]*)(\n|$)/gm;
const H5_REGEXP = /^#{5}\s/;
const H5_REGEXP_MULTIPLE = /^(#{5}\s)([^\n]*)(\n|$)/gm;
const H6_REGEXP = /^#{6}\s/;
const H6_REGEXP_MULTIPLE = /^(#{6}\s)([^\n]*)(\n|$)/gm;
const UL_REGEXP = /^[*\-+]\s/;
const UL_REGEXP_MULTIPLE = /^([*\-+]\s)([^\n]*)(\n|$)/gm;
const OL_REGEXP = /^\d+\.\s+/;
const OL_REGEXP_MULTIPLE = /^(\d+\.\s)([^\n]*)(\n|$)/gm;
const CODE_REGEXP = /^``````/;
const QUOTE_REGEXP = /^\>\s|\>/;
const QUOTE_REGEXP_MULTIPLE = /^(\>\s|\>)([^\n]*)(\n|$)/gm;
function header(size, doc, erase, multiple = false) {
    let single = new RegExp(`^#{${size}}\\s`);
    let multi = new RegExp(`^(#{${size}}\\s)([^\\n]*)(\\n|$)`, 'gm');
    let line = new RegExp(`^(#{${size}}\\s)([^\\n]*)(\\n|$)`, 'gm');
    let start = doc.getCursor('start');
    let end = doc.getCursor('end');
    let origin = doc.getRange({ line: start.line, ch: 0 }, end);
    let replacement = '';
    let symbol = Array(size).fill('#').join('');
    let startOffset = 0, endOffset = 0;
    if (erase) {
        replacement = origin.replace(multi, (_match, $1, $2, $3) => {
            endOffset = $1.length;
            return `${$2}${$3}`;
        });
        startOffset = doc.getLine(start.line).match(single) ? -size - 1 : 0;
        endOffset = doc.getLine(end.line).match(single) ? -endOffset : 0;
    }
    else {
        replacement = origin
            .replace(/^(#{1,6}\s)([^\n]*)(\n|$)/gm, (_match, _$1, $2, $3) => `${$2}${$3}`)
            .replace(LINE_REGEXP, match => !match.trim() && multiple ? match : `${symbol} ${match}`);
        startOffset = doc.getLine(start.line).match(single) ? 0 : size + 1;
        endOffset = doc.getLine(end.line).match(single) ? 0 : size + 1;
    }
    doc.replaceRange(replacement, { line: start.line, ch: 0 }, end);
    doc.setSelection({ line: start.line, ch: start.ch + startOffset }, { line: end.line, ch: end.ch + (multiple ? endOffset : startOffset) }, { scroll: false });
}
function h1(doc, erase, multiple = false) {
    header(1, doc, erase, multiple);
}
function h2(doc, erase, multiple = false) {
    header(2, doc, erase, multiple);
}
function h3(doc, erase, multiple = false) {
    header(3, doc, erase, multiple);
}
function h4(doc, erase, multiple = false) {
    header(4, doc, erase, multiple);
}
function h5(doc, erase, multiple = false) {
    header(5, doc, erase, multiple);
}
function h6(doc, erase, multiple = false) {
    header(6, doc, erase, multiple);
}
function ul(doc, erase, multiple = false) {
    let start = doc.getCursor('start');
    let end = doc.getCursor('end');
    let origin = doc.getRange({ line: start.line, ch: 0 }, end);
    let replacement = '';
    let startOffset = 0, endOffset = 0;
    if (erase) {
        replacement = origin.replace(UL_REGEXP_MULTIPLE, (_match, $1, $2, $3) => {
            endOffset = $1.length;
            return `${$2}${$3}`;
        });
        startOffset = doc.getLine(start.line).match(UL_REGEXP) ? -2 : 0;
        endOffset = doc.getLine(end.line).match(UL_REGEXP) ? -endOffset : 0;
    }
    else {
        replacement = origin.replace(LINE_REGEXP, match => !match.trim() && multiple ? match : `- ${match}`);
        startOffset = doc.getLine(start.line).match(UL_REGEXP) ? 0 : 2;
        endOffset = doc.getLine(end.line).match(UL_REGEXP) ? 0 : 2;
    }
    doc.replaceRange(replacement, { line: start.line, ch: 0 }, end);
    doc.setSelection({ line: start.line, ch: start.ch + startOffset }, { line: end.line, ch: end.ch + (multiple ? endOffset : startOffset) }, { scroll: false });
}
function ol(doc, erase, multiple = false) {
    let start = doc.getCursor('start');
    let end = doc.getCursor('end');
    let origin = doc.getRange({ line: start.line, ch: 0 }, end);
    let replacement = '';
    let startOffset = 0, index = 0, endOffset = 0;
    if (erase) {
        replacement = origin.replace(OL_REGEXP_MULTIPLE, (_match, $1, $2, $3) => {
            startOffset = startOffset > 0 ? startOffset : $1.length;
            endOffset = $1.length;
            return `${$2}${$3}`;
        });
        startOffset = doc.getLine(start.line).match(OL_REGEXP) ? -startOffset : 0;
        endOffset = doc.getLine(end.line).match(OL_REGEXP) ? -endOffset : 0;
    }
    else {
        replacement = origin.replace(LINE_REGEXP, match => !match.trim() && multiple ? match : `${++index}. ${match}`);
        startOffset = doc.getLine(start.line).match(OL_REGEXP) ? 0 : 3;
        endOffset = doc.getLine(end.line).match(OL_REGEXP) ? 0 : index.toString().length + 2;
    }
    doc.replaceRange(replacement, { line: start.line, ch: 0 }, end);
    doc.setSelection({ line: start.line, ch: start.ch + startOffset }, { line: end.line, ch: end.ch + (multiple ? endOffset : startOffset) }, { scroll: false });
}
function link(doc, _erase, _multiple = false) {
    const start = doc.getCursor('start');
    const end = doc.getCursor('end');
    const selection = doc.getSelection() || '', from = { line: start.line, ch: start.ch + 1 }, to = { line: end.line, ch: end.ch + (start.line === end.line ? 1 : 0) };
    doc.replaceRange(`[${selection}](http://)`, start, end, selection);
    doc.setSelection(from, to, { scroll: false });
}
function image(doc, _erase, _multiple = false) {
    const start = doc.getCursor('start');
    const end = doc.getCursor('end');
    const selection = doc.getSelection(), from = { line: start.line, ch: start.ch + 2 }, to = { line: end.line, ch: end.ch + (start.line === end.line ? 2 : 0) };
    doc.replaceRange(`![${selection}](http://)`, start, end, selection);
    doc.setSelection(from, to, { scroll: false });
}
function table(doc, _erase, _multiple = false) {
    let template = `
| Column 1 | Column 2 | Column 3 |
| -------- | -------- | -------- |
| Text     | Text     | Text     |
`;
    const end = doc.getCursor('end');
    doc.replaceRange(template, { line: end.line + 1, ch: 0 });
}
function bold(doc, _erase, _multiple = false) {
    const start = doc.getCursor('start');
    const end = doc.getCursor('end');
    const selection = doc.getSelection() || '', from = { line: start.line, ch: start.ch + 2 }, to = { line: end.line, ch: end.ch + (start.line === end.line ? 2 : 0) };
    doc.replaceRange(`**${selection}**`, start, end, selection);
    doc.setSelection(from, to, { scroll: false });
}
function italic(doc, _erase, _multiple = false) {
    const start = doc.getCursor('start');
    const end = doc.getCursor('end');
    const selection = doc.getSelection() || '', from = { line: start.line, ch: start.ch + 1 }, to = { line: end.line, ch: end.ch + (start.line === end.line ? 1 : 0) };
    doc.replaceRange(`*${selection}*`, start, end, selection);
    doc.setSelection(from, to, { scroll: false });
}
function strikethrough(doc, _erase, _multiple = false) {
    const start = doc.getCursor('start');
    const end = doc.getCursor('end');
    const selection = doc.getSelection() || '', from = { line: start.line, ch: start.ch + 2 }, to = { line: end.line, ch: end.ch + (start.line === end.line ? 2 : 0) };
    doc.replaceRange(`~~${selection}~~`, start, end, selection);
    doc.setSelection(from, to, { scroll: false });
}
function code(doc, _erase, _multiple = false) {
    const start = doc.getCursor('start');
    const end = doc.getCursor('end');
    const endLine = doc.getLine(end.line);
    const from = Object.assign(Object.assign({}, start), { ch: 0 });
    const to = Object.assign(Object.assign({}, end), { ch: endLine.length });
    const selection = doc.getRange(from, to);
    doc.replaceRange(`\`\`\`
${selection}
\`\`\`
`, from, to, selection);
    doc.setCursor(start.line, 3);
}
function quote(doc, erase, multiple = false) {
    let start = doc.getCursor('start');
    let end = doc.getCursor('end');
    let origin = doc.getRange({ line: start.line, ch: 0 }, end);
    let replacement = '';
    let startOffset = 0, endOffset = 0;
    if (erase) {
        replacement = origin.replace(QUOTE_REGEXP_MULTIPLE, (_match, $1, $2, $3) => {
            endOffset = $1.length;
            return `${$2}${$3}`;
        });
        startOffset = doc.getLine(start.line).match(QUOTE_REGEXP) ? -2 : 0;
        endOffset = doc.getLine(end.line).match(QUOTE_REGEXP) ? -endOffset : 0;
    }
    else {
        replacement = origin.replace(LINE_REGEXP, match => !match.trim() && multiple ? match : `> ${match}`);
        startOffset = doc.getLine(start.line).match(QUOTE_REGEXP) ? 0 : 2;
        endOffset = doc.getLine(end.line).match(QUOTE_REGEXP) ? 0 : 2;
    }
    doc.replaceRange(replacement, { line: start.line, ch: 0 }, end);
    doc.setSelection({ line: start.line, ch: start.ch + startOffset }, { line: end.line, ch: end.ch + (multiple ? endOffset : startOffset) }, { scroll: false });
}
const commands = {
    bold, italic, strikethrough,
    h1, h2, h3, h4, h5, h6,
    ul, ol,
    code, quote,
    link, image, table
};

class NtMarkdownEditorConfig {
    constructor() {
        this.actions = [
            ['bold', 'italic', 'strikethrough'],
            ['h1', 'h2', 'h3', 'h4', 'h5', 'h6'],
            ['code', 'quote'],
            ['ul', 'ol'],
            ['link', 'image', 'table'],
            ['preview', 'help']
        ];
    }
}
const NT_MARKDOWN_EDITOR_CONFIG = new InjectionToken('nt-markdown-editor-config');

const DEFAULT_MARKDOWN_EDITOR_ICONS = {
    bold: 'fa fa-bold',
    italic: 'fa fa-italic',
    strikethrough: 'fa fa-strikethrough',
    h1: 'fa fa-heading fa-heading-x fa-heading-1',
    h2: 'fa fa-heading fa-heading-x fa-heading-2',
    h3: 'fa fa-heading fa-heading-x fa-heading-3',
    h4: 'fa fa-heading fa-heading-x fa-heading-4',
    h5: 'fa fa-heading fa-heading-x fa-heading-5',
    h6: 'fa fa-heading fa-heading-x fa-heading-6',
    code: 'fa fa-code',
    quote: 'fa fa-quote-left',
    ul: 'fa fa-list-ul',
    ol: 'fa fa-list-ol',
    link: 'fa fa-link',
    image: 'fa fa-image',
    table: 'fa fa-table',
    line: 'fa fa-minus',
    preview: 'fas fa-columns',
    help: 'fab fa-markdown',
    undo: 'fa fa-reply',
    redo: 'fa fa-share',
    fill: 'fa fa-arrows-alt',
    compress: 'fa fa-compress'
};
const NT_MARKDOWN_EDITOR_ICONS = new InjectionToken('nt-markdown-editor-icons');

var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var NtMarkdownEditorComponent_1;
const DEFAULT_MIN_ROWS = 10, DEFAULT_MAX_ROWS = 20, MIN_ROWS_VALUE = 1, MAX_ROWS_VALUE = 100;
let NtMarkdownEditorComponent = NtMarkdownEditorComponent_1 = class NtMarkdownEditorComponent extends NtFormFieldControl {
    constructor(_renderer, _changeDetectorRef, platformId, ngControl, _icons, _config) {
        super();
        this._renderer = _renderer;
        this._changeDetectorRef = _changeDetectorRef;
        this.platformId = platformId;
        this.ngControl = ngControl;
        this._destroy = new Subject();
        this._syncScrollElements = [];
        this._syncScrollEvent = new Subject();
        this._value = '';
        this.fillScreen = false;
        this.previewMode = false;
        this.activeActions = [];
        this.activeActionsSnapshot = [];
        this._minHeight = `100px`;
        this._maxHeight = `100px`;
        this._focused = false;
        this.placeholder = '';
        this._disabled = false;
        this._required = false;
        this._minRows = DEFAULT_MIN_ROWS;
        this._maxRows = DEFAULT_MAX_ROWS;
        this._theme = 'default';
        this._onChange = () => { };
        this._onTouched = () => { };
        if (this.ngControl) {
            this.ngControl.valueAccessor = this;
        }
        this.config = Object.assign(Object.assign({}, new NtMarkdownEditorConfig()), _config);
        this.icons = Object.assign(Object.assign({}, DEFAULT_MARKDOWN_EDITOR_ICONS), _icons);
    }
    set value(value) {
        this._value = value;
        if (this.instance) {
            this.instance.setValue(value);
        }
    }
    get value() { return this._value; }
    get empty() { return !this.value; }
    get focused() { return this._focused; }
    set disabled(value) { this._disabled = coerceBooleanProperty(value); }
    get disabled() { return this._disabled; }
    get required() { return this._required; }
    set required(value) { this._required = coerceBooleanProperty(value); }
    get minRows() { return this._minRows; }
    set minRows(value) {
        const newValue = coerceNumberProperty(value) || 0;
        this._minRows = newValue < MIN_ROWS_VALUE ? MIN_ROWS_VALUE : newValue;
    }
    get maxRows() { return this._maxRows; }
    set maxRows(value) {
        const newValue = coerceNumberProperty(value) || 0;
        this._maxRows = newValue > MAX_ROWS_VALUE ? MAX_ROWS_VALUE : newValue;
    }
    get theme() { return this._theme; }
    set theme(value) { this._theme = value; }
    get history() {
        if (this.instance) {
            const doc = this.instance.getDoc();
            return doc.historySize();
        }
        return { undo: 0, redo: 0 };
    }
    ngOnInit() {
        if (isPlatformBrowser(this.platformId)) {
            this._codeMirrorInit();
        }
    }
    ngOnChanges(changes) {
        const rowChanges = changes.minRows || changes.maxRows;
        if (rowChanges && !rowChanges.firstChange) {
            this._setEditorHeightRange();
        }
    }
    ngOnDestroy() {
        this._destroy.next();
        this._destroy.complete();
        this._unsubscribeScrolls();
    }
    writeValue(value) {
        this.value = value;
    }
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    focus() {
        if (!this.disabled) {
            this.instance.focus();
        }
    }
    setDisabledState(isDisabled) {
        this._disabled = isDisabled;
    }
    execCommand(type) {
        if (type === 'preview') {
            this.previewMode = !this.previewMode;
            this._actionMatches();
            setTimeout(() => {
                this.instance.refresh();
                this.previewMode ? this._subscribeScrolls() : this._unsubscribeScrolls();
            });
        }
        else if (type === 'help') {
            window.open('https://guides.github.com/features/mastering-markdown/', '_blank');
        }
        else {
            const activeted = this.activeActions.indexOf(type) > -1;
            const doc = this.instance.getDoc();
            const start = doc.getCursor('start');
            const end = doc.getCursor('end');
            const multiple = end.line - start.line > 0;
            const command = commands[type];
            command && command(doc, activeted, multiple);
            this.instance.save();
            this.instance.focus();
        }
    }
    undo() {
        this.instance.getDoc().undo();
    }
    redo() {
        this.instance.getDoc().redo();
    }
    changeScreenFilled(fillScreen) {
        this.fillScreen = fillScreen;
        this.instance.refresh();
        this._setEditorHeightRange();
    }
    _subscribeScrolls() {
        const callback = (event) => {
            const element = event.target;
            const scrollYUpdated = element.scrollTop !== element.previousScrollY;
            if (scrollYUpdated) {
                this._scrollTo(element);
            }
            element.previousScrollY = element.scrollTop;
        };
        const editorScrollElement = this.instance.getScrollerElement();
        this._syncScrollElements.push(editorScrollElement, this.markdown.nativeElement);
        this._syncScrollElements.forEach(element => element.addEventListener('scroll', element.callback = callback));
        this._syncScrollSubscription = this._syncScrollEvent.subscribe((event) => {
            this._syncScrollElements
                .filter(element => event.owner !== element)
                .forEach(element => {
                scrollY = element.previousScrollY = Math.round(event.rateY * (element.scrollHeight - element.clientHeight));
                if (Math.round(element.scrollTop - scrollY)) {
                    element.scrollTop = scrollY;
                }
            });
        });
        this._scrollTo(editorScrollElement);
    }
    _unsubscribeScrolls() {
        if (this._syncScrollSubscription && !this._syncScrollSubscription.closed) {
            this._syncScrollSubscription.unsubscribe();
        }
        if (this._syncScrollElements) {
            this._syncScrollElements.forEach(element => element.removeEventListener('scroll', element.callback));
            this._syncScrollElements = [];
        }
    }
    _scrollTo(element) {
        this._syncScrollEvent.next({
            scrollY: element.scrollTop,
            rateY: element.scrollTop / (element.scrollHeight - element.clientHeight),
            owner: element
        });
    }
    _codeMirrorInit() {
        if (typeof fromTextArea === 'function') {
            this.editor.nativeElement.value = this.value;
            this.instance = fromTextArea(this.editor.nativeElement, {
                mode: 'gfm',
                lineWrapping: true,
                theme: this.theme || 'default',
                placeholder: this.placeholder,
                extraKeys: { Enter: 'newlineAndIndentContinueMarkdownList' },
            });
            this._setEditorHeightRange();
            this.instance.on('change', this._onCodeMirrorChange.bind(this));
            this.instance.on('cursorActivity', this._onCodeMirrorCursorActivity.bind(this));
            this.instance.on('focus', this._onCodeMirrorFocus.bind(this));
            this.instance.on('blur', this._onCodeMirrorBlur.bind(this));
            this._destroy.subscribe(() => {
                this.instance.off('change', this._onCodeMirrorChange);
                this.instance.off('cursorActivity', this._onCodeMirrorCursorActivity);
                this.instance.off('focus', this._onCodeMirrorFocus);
                this.instance.off('blur', this._onCodeMirrorBlur);
                this.instance.toTextArea();
                this._changeDetectorRef.markForCheck();
            });
            Promise.resolve().then(() => this.instance.refresh());
        }
    }
    _onCodeMirrorChange(instance) {
        this._actionMatches();
        this._value = instance.getValue();
        this._onChange(this._value);
        this._onTouched();
        this._changeDetectorRef.markForCheck();
    }
    _onCodeMirrorCursorActivity() {
        this._actionMatches();
        this._changeDetectorRef.markForCheck();
    }
    _onCodeMirrorFocus() {
        this._focused = true;
        this._changeDetectorRef.markForCheck();
    }
    _onCodeMirrorBlur() {
        this._focused = false;
        this._changeDetectorRef.markForCheck();
    }
    _actionMatches() {
        const doc = this.instance.getDoc();
        const start = doc.getCursor('start');
        const end = doc.getCursor('end');
        const range = doc.getRange({ line: start.line, ch: 0 }, end);
        this.activeActions = [];
        if (range.match(/^#\s/gm)) {
            this.activeActions.push('h1');
        }
        if (range.match(/^#{2}\s/gm)) {
            this.activeActions.push('h2');
        }
        if (range.match(/^#{3}\s/gm)) {
            this.activeActions.push('h3');
        }
        if (range.match(/^#{4}\s/gm)) {
            this.activeActions.push('h4');
        }
        if (range.match(/^#{5}\s/gm)) {
            this.activeActions.push('h5');
        }
        if (range.match(/^#{6}\s/gm)) {
            this.activeActions.push('h6');
        }
        if (range.match(/^[*\-+]\s/gm)) {
            this.activeActions.push('ul');
        }
        if (range.match(/^\d+\.\s+/gm)) {
            this.activeActions.push('ol');
        }
        if (range.match(/^\>+/gm)) {
            this.activeActions.push('quote');
        }
        if (this.previewMode) {
            this.activeActions.push('preview');
        }
    }
    _setEditorHeightRange() {
        if (isPlatformBrowser(this.platformId) && !!this.instance) {
            const scrollElement = this.instance.getScrollerElement();
            const style = window.getComputedStyle(scrollElement);
            if (this.fillScreen) {
                this._minHeight = `100%`;
                this._maxHeight = `100%`;
                this._renderer.setStyle(scrollElement, 'min-height', this._minHeight);
                this._renderer.setStyle(scrollElement, 'max-height', this._maxHeight);
            }
            else if (style && style.lineHeight) {
                const lineHeight = parseFloat(style.lineHeight.replace('px', ''));
                this._minHeight = `${this.minRows * lineHeight}px`;
                this._maxHeight = `${this.maxRows * lineHeight}px`;
                this._renderer.setStyle(scrollElement, 'min-height', this._minHeight);
                this._renderer.setStyle(scrollElement, 'max-height', this._maxHeight);
            }
        }
    }
};
NtMarkdownEditorComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: ChangeDetectorRef },
    { type: Object, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] },
    { type: NgControl, decorators: [{ type: Optional }, { type: Self }] },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [NT_MARKDOWN_EDITOR_ICONS,] }] },
    { type: NtMarkdownEditorConfig, decorators: [{ type: Optional }, { type: Inject, args: [NT_MARKDOWN_EDITOR_CONFIG,] }] }
];
__decorate([
    ViewChild('editor', { static: true })
], NtMarkdownEditorComponent.prototype, "editor", void 0);
__decorate([
    ViewChild('markdown', { static: false, read: ElementRef })
], NtMarkdownEditorComponent.prototype, "markdown", void 0);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "value", null);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "placeholder", void 0);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "disabled", null);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "required", null);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "minRows", null);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "maxRows", null);
__decorate([
    Input()
], NtMarkdownEditorComponent.prototype, "theme", null);
NtMarkdownEditorComponent = NtMarkdownEditorComponent_1 = __decorate([
    Component({
        selector: 'nt-markdown-editor',
        template: "<div class=\"nt-markdown-editor-tools\" [class.tools-disable]=\"previewMode\">\n  <div class=\"tools-group\" *ngFor=\"let group of config.actions\">\n    <div class=\"tools-item\" *ngFor=\"let action of group\"\n    [class.active]=\"activeActions.indexOf(action) > -1\"\n    (click)=\"execCommand(action)\">\n      <span [class]=\"icons[action]\"></span>\n    </div>\n  </div>\n  <div class=\"tools-group\">\n    <div class=\"tools-item\" [class.disabled]=\"history.undo === 0\" (click)=\"undo()\">\n      <span [class]=\"icons['undo']\"></span>\n    </div>\n    <div class=\"tools-item\" [class.disabled]=\"history.redo === 0\" (click)=\"redo()\">\n      <span [class]=\"icons['redo']\"></span>\n    </div>\n  </div>\n  <div class=\"tools-group\">\n    <div class=\"tools-item\" (click)=\"changeScreenFilled(true)\" *ngIf=\"!fillScreen\">\n      <span [class]=\"icons['fill']\"></span>\n    </div>\n    <div class=\"tools-item\" (click)=\"changeScreenFilled(false)\" *ngIf=\"fillScreen\">\n      <span [class]=\"icons['compress']\"></span>\n    </div>\n  </div>\n</div>\n<div class=\"nt-markdown-editor-container\">\n  <div class=\"nt-markdown-editor-content\">\n    <textarea #editor></textarea>\n  </div>\n  <div #markdown class=\"nt-markdown-editor-preview\"\n    *ngIf=\"previewMode\"\n    [style.minHeight]=\"_minHeight\"\n    [style.maxHeight]=\"_maxHeight\"\n    [@fade]>\n    <nt-markdown [data]=\"value\"></nt-markdown>\n  </div>\n</div>\n",
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush,
        providers: [
            { provide: NtFormFieldControl, useExisting: NtMarkdownEditorComponent_1 }
        ],
        animations: [
            trigger('fade', [
                transition('void => *', fadeIn(.15))
            ])
        ],
        host: {
            'class': 'nt-markdown-editor nt-form-control',
            '[class.focus]': 'focused',
            '[class.fill-screen]': 'fillScreen'
        }
    }),
    __param(2, Inject(PLATFORM_ID)),
    __param(3, Optional()), __param(3, Self()),
    __param(4, Optional()), __param(4, Inject(NT_MARKDOWN_EDITOR_ICONS)),
    __param(5, Optional()), __param(5, Inject(NT_MARKDOWN_EDITOR_CONFIG))
], NtMarkdownEditorComponent);

var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
let NtMarkdownEditorModule = class NtMarkdownEditorModule {
};
NtMarkdownEditorModule = __decorate$1([
    NgModule({
        imports: [
            CommonModule,
            NtMarkdownModule
        ],
        exports: [
            NtMarkdownModule,
            NtMarkdownEditorComponent
        ],
        declarations: [
            NtMarkdownEditorComponent
        ],
    })
], NtMarkdownEditorModule);

export { DEFAULT_MARKDOWN_EDITOR_ICONS, NT_MARKDOWN_EDITOR_ICONS, NtMarkdownEditorComponent, NtMarkdownEditorModule, NtMarkdownEditorConfig as ɵa, NT_MARKDOWN_EDITOR_CONFIG as ɵb };
//# sourceMappingURL=markdown-editor.js.map
